summaryrefslogtreecommitdiffstats
path: root/tdecore/kmimesourcefactory.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:16:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:16:51 -0600
commitf2bfcad7ffdd09911f282afe2a2051b3708601c9 (patch)
treece4bebc206b6f9753745218e6a4c4368df624c16 /tdecore/kmimesourcefactory.h
parenta14eaa044240517f1f3d7eb5dacbff96fd447ada (diff)
downloadtdelibs-f2bfcad7ffdd09911f282afe2a2051b3708601c9.tar.gz
tdelibs-f2bfcad7ffdd09911f282afe2a2051b3708601c9.zip
Rename KIcon to enhance compatibility with KDE4
Diffstat (limited to 'tdecore/kmimesourcefactory.h')
-rw-r--r--tdecore/kmimesourcefactory.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdecore/kmimesourcefactory.h b/tdecore/kmimesourcefactory.h
index e18c7d888..16302dfe4 100644
--- a/tdecore/kmimesourcefactory.h
+++ b/tdecore/kmimesourcefactory.h
@@ -29,7 +29,7 @@ class KMimeSourceFactoryPrivate;
class TDEInstance;
/**
* An extension to TQMimeSourceFactory that uses KIconLoader to
* find images.
*
* Normally you don't have to instantiate this class at all, TDEApplication does that for
@@ -46,7 +46,7 @@ public:
*
* @param loader is the iconloader used to find images.
*/
- KMimeSourceFactory (KIconLoader* loader = TDEGlobal::iconLoader());
+ KMimeSourceFactory (TDEIconLoader* loader = TDEGlobal::iconLoader());
/**
* Destructor.
@@ -29,7 +29,7 @@ class KMimeSourceFactoryPrivate;
class TDEInstance;
/**
- * An extension to TQMimeSourceFactory that uses KIconLoader to
+ * An extension to TQMimeSourceFactory that uses TDEIconLoader to
* find images.
*